Package: epiR
Version: 2.0.95
Date: 2026-07-17
Title: Tools for the Analysis of Epidemiological Data
Authors@R: c(person(given = "Mark", family = "Stevenson", role = c("aut", "cre"), email = "mark.stevenson1@unimelb.edu.au", comment = c(ORCID = "0000-0003-1890-9784")),
   person(given = "Evan", family = "Sergeant", role = "aut", email = "evansergeant@gmail.com"),
   person(given = "Cord", family = "Heuer", role = "ctb"),
   person(given = "Telmo", family = "Nunes", role = "ctb"),
   person(given = "Cord", family = "Heuer", role = "ctb"),
   person(given = "Jonathon", family = "Marshall", role = "ctb"),
   person(given = "Javier", family = "Sanchez", role = "ctb"),
   person(given = "Ron", family = "Thornton", role = "ctb"),
   person(given = "Jeno", family = "Reiczigel", role = "ctb"),
   person(given = "Jim", family = "Robison-Cox", role = "ctb"),
   person(given = "Paola", family = "Sebastiani", role = "ctb"),
   person(given = "Peter", family = "Solymos", role = "ctb"),
   person(given = "Kazuki", family = "Yoshida", role = "ctb"),
   person(given = "Geoff", family = "Jones", role = "ctb"),
   person(given = "Sarah", family = "Pirikahu", role = "ctb"),
   person(given = "Simon", family = "Firestone", role = "ctb"),
   person(given = "Ryan", family = "Kyle", role = "ctb"),
   person(given = "Johann", family = "Popp", role = "ctb"),
   person(given = "Mathew", family = "Jay", role = "ctb"),
   person(given = "Allison", family = "Cheung", role = "ctb"),
   person(given = "Nagendra", family = "Singanallur", role = "ctb"),
   person(given = "Aniko", family = "Szabo", role = "ctb"),
   person(given = "Ahmad", family = "Rabiee", role = "ctb"))
Maintainer: Mark Stevenson <mark.stevenson1@unimelb.edu.au>
Description: Tools for the analysis of epidemiological and surveillance data. Contains functions for directly and indirectly adjusting measures of disease frequency, quantifying measures of association on the basis of single or multiple strata of count data presented in a contingency table, computation of confidence intervals around incidence risk and incidence rate estimates and sample size calculations for cross-sectional, case-control and cohort studies. Surveillance tools include functions to calculate an appropriate sample size for 1- and 2-stage representative freedom surveys, functions to estimate surveillance system sensitivity and functions to support scenario tree modelling analyses.   
Depends: R (>= 3.0.0), survival
Imports: BiasedUrn, pander, methods, sf, lubridate, zoo, flextable,
        stats, officer
Suggests: MASS (>= 3.1-20), dplyr, foreign, ggplot2, knitr, rmarkdown,
        bookdown, plyr, RColorBrewer, scales, sp, spData (>= 2.3.0),
        spatstat, tidyr
VignetteBuilder: knitr
License: GPL (>= 2)
Packaged: 2026-07-17 04:20:40 UTC; marks1
RoxygenNote: 7.1.0
NeedsCompilation: no
Author: Mark Stevenson [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1890-9784>),
  Evan Sergeant [aut],
  Cord Heuer [ctb],
  Telmo Nunes [ctb],
  Cord Heuer [ctb],
  Jonathon Marshall [ctb],
  Javier Sanchez [ctb],
  Ron Thornton [ctb],
  Jeno Reiczigel [ctb],
  Jim Robison-Cox [ctb],
  Paola Sebastiani [ctb],
  Peter Solymos [ctb],
  Kazuki Yoshida [ctb],
  Geoff Jones [ctb],
  Sarah Pirikahu [ctb],
  Simon Firestone [ctb],
  Ryan Kyle [ctb],
  Johann Popp [ctb],
  Mathew Jay [ctb],
  Allison Cheung [ctb],
  Nagendra Singanallur [ctb],
  Aniko Szabo [ctb],
  Ahmad Rabiee [ctb]
Repository: CRAN
Date/Publication: 2026-07-17 08:40:02 UTC
Built: R 4.6.1; ; 2026-07-17 12:34:55 UTC; unix
