# Export all names. Internal (undocumented functions are not included)

export(epi.2by2)
export(epi.about)
export(epi.asc)
export(epi.betabuster)
export(epi.blcm.paras)
export(epi.bohning)     
export(epi.ccc)
export(epi.conf)
export(epi.convgrid)
export(epi.cp)
export(epi.cpresids)
export(epi.descriptives)
export(epi.dgamma)
export(epi.directadj)
export(epi.dms)         
export(epi.dsl)
export(epi.edr)
export(epi.empbayes)
export(epi.evalue)
export(epi.fpos)
export(epi.herdtest)
export(epi.indirectadj)
export(epi.insthaz)
export(epi.interaction)
export(epi.iv)          
export(epi.kappa)
export(epi.ltd)
export(epi.mbf)
export(epi.mh)
export(epi.nomogram)    
export(epi.occc)
export(epi.offset)
export(epi.pooled)      
export(epi.popsize)
export(epi.prcc)
export(epi.prev)
export(epi.psi)
export(epi.realrisk)  
export(epi.RtoBUGS)     
export(epi.smd)
export(epi.smr)
export(epi.sscc)
export(epi.ssclus1estb) 
export(epi.ssclus1estc)
export(epi.ssclus2estb)
export(epi.ssclus2estc)
export(epi.sscohortc)
export(epi.sscohortt)   
export(epi.sscompb)
export(epi.sscompc)
export(epi.sscomps)
export(epi.ssdetect)
export(epi.ssdxsesp)
export(epi.ssequb)      
export(epi.ssequc)
export(epi.ssninfb)
export(epi.ssninfc)
export(epi.sssimpleestb)
export(epi.sssimpleestc)
export(epi.ssstrataestb)
export(epi.ssstrataestc)
export(epi.sssupb)
export(epi.sssupc)
export(epi.ssxsectn)
export(epi.ssdxtest)  
export(epi.tests) 


# ------------------------------------------------------------------------------------
# Representative sampling - sample size probability of disease freedom:
export(rsu.sspfree.rs)

# Representative sampling - sample size surveillance system sensitivity:
export(rsu.sssep.rs)
export(rsu.sssep.rs2st)
export(rsu.sssep.rsfreecalc)
export(rsu.sssep.rspool)

# Representative sampling - calculate surveillance system sensitivity:
export(rsu.sep.rs)
export(rsu.sep.rs2st)
export(rsu.sep.rsmult)
export(rsu.sep.rsfreecalc)
export(rsu.sep.rspool)
export(rsu.sep.rsvarse)

# Representative sampling - calculate surveillance system specificity:
export(rsu.spp.rs)

# Representative sampling - probability of disease freedom:
export(rsu.pfree.rs)
export(rsu.pfree.equ)


# ------------------------------------------------------------------------------------
# Risk-based sampling - sample size surveillance system sensitivity:
export(rsu.sssep.rbsrg)
export(rsu.sssep.rbmrg)
export(rsu.sssep.rb2st1rf)
export(rsu.sssep.rb2st2rf)

# Risk-based sampling - calculate surveillance system sensitivity:
export(rsu.sep.rb)
export(rsu.sep.rb1rf)
export(rsu.sep.rb2rf)
export(rsu.sep.rbvarse)
export(rsu.sep.rb2st)

# Census:
export(rsu.sep.cens)

# Passive:
export(rsu.sep.pass)

# Miscellaneous functions:
export(rsu.adjrisk)
export(rsu.dxtest)
export(rsu.epinf)
export(rsu.pstar)
export(rsu.sep)


S3method(print, epi.2by2)
S3method(summary, epi.2by2)
S3method(print, epi.tests)
S3method(summary, epi.tests)
S3method(print, epi.occc)
S3method(summary, epi.occc)

# Import all packages listed as Imports or Depends
import(survival)
import(pander)
import(sf)
import(lubridate)
importFrom(BiasedUrn, dFNCHypergeo)
importFrom("graphics", "hist")
importFrom("methods", "slot")
importFrom("stats", "xtabs", "anova", "aov", "addmargins", "complete.cases", "confint", "chisq.test", "cor", "cov", "dbinom", "fisher.test", "glm", "lm", "mantelhaen.test", "model.matrix", "optimize", "pbeta", "pbinom", "pchisq", "phyper", "pnorm", "pt", "qbeta", "qbinom", "qchisq", "qf", "qgamma", "qnorm", "qpois", "qt", "quantile", "rbeta", "rpois", "sd", "uniroot", "var", "vcov", "confint.default")
importFrom("zoo", "rollmean")
importFrom("flextable","flextable", "width", "font", "set_header_df", "bg", "hline_top", "align", "fontsize", "footnote", "set_caption")
importFrom("officer","fp_border")
importFrom("survival","coxph")
importFrom("utils", "packageDescription", "write.table")